Supports data-driven composition of a main plot with associated subplots that need precise axis alignment. Unlike general layout-focused tools such as 'cowplot' and 'patchwork', it enables related subplots to be integrated on the top, bottom, left, or right sides of a main plot with matched axes, so that the combined panels can be interpreted as a coherent whole. This design was inspired by the 'Method 2' described in 'ggtree' (G Yu (2018) tools:::Rd_expr_doi("10.1093/molbev/msy194")).
Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID)
Authors:
Guangchuang Yu guangchuangyu@gmail.com (ORCID)
Other contributors:
Shuangbin Xu xshuangbin@163.com (ORCID) [contributor]
Thomas Hackl thackl@mit.edu [contributor]