| set_panel_spacing | R Documentation |
Set panel spacing for an 'aplot' object
set_panel_spacing(x, spacing = 0)
x |
an 'aplot' object |
spacing |
a non-negative numeric value in millimeters, or '"asis"' |
Control the spacing between aligned panels when an 'aplot' object is rendered. Numeric values are interpreted in millimeters and represent the gap between neighboring panels. Use '"asis"' to preserve the subplot margins already defined in each plot.
an 'aplot' object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.