Learn R Programming

aplot (version 0.3.1)

set_panel_spacing: set_panel_spacing

Description

Set panel spacing for an 'aplot' object

Usage

set_panel_spacing(x, spacing = 0)

Value

an 'aplot' object

Arguments

x

an 'aplot' object

spacing

a non-negative numeric value in millimeters, or `"asis"`

Details

Control the spacing between aligned panels when an 'aplot' object is rendered. Numeric values are interpreted in millimeters and represent the gap between neighboring panels. Use `"asis"` to preserve the subplot margins already defined in each plot.